@@ -244,6 +244,7 @@ assert(len(group2.members.list()) == 2)
 
 group1.members.delete(user1.id)
 assert(len(group1.members.list()) == 2)
+assert(len(group1.members.all()))
 member = group1.members.get(user2.id)
 member.access_level = gitlab.const.OWNER_ACCESS
 member.save()
@@ -390,7 +391,7 @@ data = {
     ]
 }
 admin_project.commits.create(data)
-assert('---' in admin_project.commits.list()[0].diff()[0]['diff'])
+assert('@@' in admin_project.commits.list()[0].diff()[0]['diff'])
 
 # commit status
 commit = admin_project.commits.list()[0]
@@ -539,6 +540,15 @@ assert(isinstance(issue1.user_agent_detail(), dict))
 assert(issue1.user_agent_detail()['user_agent'])
 assert(issue1.participants())
 
+# issues labels and events
+label2 = admin_project.labels.create({'name': 'label2', 'color': '#aabbcc'})
+issue1.labels = ['label2']
+issue1.save()
+events = issue1.resourcelabelevents.list()
+assert(events)
+event = issue1.resourcelabelevents.get(events[0].id)
+assert(event)
+
 discussion = issue1.discussions.create({'body': 'Discussion body'})
 assert(len(issue1.discussions.list()) == 1)
 d_note = discussion.notes.create({'body': 'first note'})
@@ -628,6 +638,14 @@ d_note_from_get.delete()
 discussion = mr.discussions.get(discussion.id)
 assert(len(discussion.attributes['notes']) == 1)
 
+# mr labels and events
+mr.labels = ['label2']
+mr.save()
+events = mr.resourcelabelevents.list()
+assert(events)
+event = mr.resourcelabelevents.get(events[0].id)
+assert(event)
+
 # basic testing: only make sure that the methods exist
 mr.commits()
 mr.changes()
